% This matlab file reads the transmission loss data generated by Run Validation - FMM,
% and plots the results in matlab figures.
% The TL from Coustyx is compared with 
%   (a) analytical solution obtained from 1-D plane wave assumption
%   (b) experiment measurements extracted from the paper,
%      "Tao, Z. and Seybert, A.F., A review of current techniques for
%       measuring muffler transmission loss, SAE International, 2003."

%********************************************************************
clear all;
% Acoustic medium properties:
%  rho_o = medium density of air = 4.371403E-005 lb/inch^3
%  c = speed of sound = 13503.937 inch/s
rho_o = 4.371403E-005;
c = 13503.937;
zo = rho_o*c;

%********************************************************************
%Input:
%  (1) Run "RunValidation - FMM" in the Demo Model before running 
%      this matlab script to obtain file 'validation_results_fmm.txt'
%  (2) Read experimental results, Make sure the 'TL_experiment.txt'
%      provided with the demo model is in the current folder 
%********************************************************************
TL_coustyx = load('validation_results_fmm.txt');
% The results file has 4 columns, where
% TL_coustyx(:,1) = k (wave number)
% TL_coustyx(:,2) = frequency (Hz)
% TL_coustyx(:,3) = transmission loss computed from Coustyx analysis
% TL_coustyx(:,4) = transmission loss computed from analytical solution 
%                from 1-D assumption
TL_exp = load('TL_experiment.txt');
% The file has 2 columns, where
% TL_exp(:,1) = frequency (Hz)
% TL_exp(:,2) = transmission loss extracted from the published paper
%********************************************************************

%********************************************************************
%Output:
%  Plot comparisons between FMM and Analytical results
%********************************************************************
figure;
plot(TL_coustyx(:,2), TL_coustyx(:,3), 'k',...
    TL_coustyx(:,2), TL_coustyx(:,4), 'b',...
    TL_exp(:,1),TL_exp(:,2),'r');
legend('Coustyx-FMM','Analy 1-D Solution','Measured');
title('Tranmission Loss Measurements');
ylim([0 50]);
xlabel('Frequency (Hz)');
ylabel('TL (dB)');
